# p11-kit needs pkcsslotd daemon starting by default
# upstream does not recommend to enable the pkcsslotd service by default.
# we disable it
%define p11_kit_support	0

%define major		0
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Implementation of the PKCS#11 (Cryptoki) specification v3.0
Name:		opencryptoki
Version:	3.24.0
Release:	%mkrel 2
License:	CPL
Group:		System/Libraries
URL:		https://github.com/opencryptoki/
Source0:	https://github.com/opencryptoki/opencryptoki/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	opencryptoki.module
Source2:	%{name}-tmpfiles.conf
# https://bugzilla.redhat.com/show_bug.cgi?id=732756
Patch0:		opencryptoki-3.11.0-group.patch
Patch1:		opencryptoki-3.24.0-p11sak.patch
Patch2:		opencryptoki-3.24.0-compile-error-due-to-incompatible-pointer-types.patch
# upstream patches
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	systemd-units
BuildRequires:	trousers-devel
BuildRequires:	libitm-devel
BuildRequires:	pkgconfig(libcap)
Requires:	p11-kit
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper

%description
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package contains the Slot Daemon (pkcsslotd) and general utilities.

%package -n	%{libname}
Summary:	The run-time libraries for opencryptoki package
Group:		System/Libraries

%description -n	%{libname}
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package contains the PKCS#11 library implementation, and requires
at least one token implementation (packaged separately) to be fully
functional.

%package -n	%{develname}
Summary:	Development files for openCryptoki
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the development header files for building
opencryptoki and PKCS#11 based applications

%package	swtok
Summary:	The software token implementation for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	swtok
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package brings the software token implementation to use opencryptoki
without any specific cryptographic hardware.

%package	tpmtok
Summary:	Trusted Platform Module (TPM) device support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	tpmtok
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package brings the necessary libraries and files to support
Trusted Platform Module (TPM) devices in the opencryptoki stack.

%package	icsftok
Summary:	ICSF token support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	icsftok
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package brings the necessary libraries and files to support
ICSF token in the opencryptoki stack.

%prep
%autosetup -p1

%build
./bootstrap.sh

%configure \
    --sharedstatedir=/var/lib \
    --with-systemd=%{_unitdir} \
    --with-pkcsslotd-user=pkcs11 --with-pkcs-group=pkcs11 \
    --disable-icatok \
    --disable-ccatok \
    --disable-ep11tok \
    --disable-pkcsep11_migrate \
    --enable-pkcscca_migrate

%make_build CHGRP=/bin/true

%install

%make_install CHGRP=/bin/true

%if 0%{?p11_kit_support}
install -Dpm 644 %{SOURCE1} %{buildroot}%{_datadir}/p11-kit/modules/opencryptoki.module
%endif

# Remove unwanted cruft
find %{buildroot} -name '*.la' -delete

%pre
%_pre_useradd pkcs11 /dev/null /sbin/nologin

%post
%_tmpfilescreate %{name}
%_post_service pkcsslotd

%preun
%_preun_service pkcsslotd

%postun
%_postun_userdel pkcs11

%files
%doc ChangeLog FAQ README.md
%doc doc/opencryptoki-howto.md
%doc doc/README.token_data
%doc %{_docdir}/%{name}/*.conf
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%attr(0640, root, pkcs11) %config(noreplace) %{_sysconfdir}/%{name}/p11sak_defined_attrs.conf
%attr(0640, root, pkcs11) %config(noreplace) %{_sysconfdir}/%{name}/strength.conf
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/pkcsslotd.service
%{_sbindir}/pkcsconf
%{_sbindir}/pkcsslotd
%{_sbindir}/pkcsstats
%{_sbindir}/p11sak
%{_sbindir}/pkcstok_migrate
%{_sbindir}/pkcshsm_mk_change
%{_sbindir}/pkcstok_admin
%{_mandir}/man1/pkcsconf.1*
%{_mandir}/man1/p11sak.1*
%{_mandir}/man1/pkcsstats.1*
%{_mandir}/man1/pkcstok_migrate.1*
%{_mandir}/man1/pkcshsm_mk_change.1*
%{_mandir}/man1/pkcstok_admin.1*
%{_mandir}/man5/%{name}.conf.5*
%{_mandir}/man5/p11sak_defined_attrs.conf.5*
%{_mandir}/man5/policy.conf.5*
%{_mandir}/man5/strength.conf.5*
%{_mandir}/man7/%{name}.7*
%{_mandir}/man8/pkcsslotd.8*
%{_libdir}/opencryptoki/methods
%{_libdir}/pkcs11/methods
%dir %attr(770,root,pkcs11) %{_sharedstatedir}/%{name}
%dir %attr(770,root,pkcs11) %ghost %{_rundir}/lock/%{name}
%dir %attr(770,root,pkcs11) %ghost %{_rundir}/lock/%{name}/*
%if 0%{?p11_kit_support}
%{_datadir}/p11-kit/modules/opencryptoki.module
%endif

%files -n %{libname}
%doc LICENSE
%{_sysconfdir}/ld.so.conf.d/*
# Unversioned .so symlinks usually belong to -devel packages, but opencryptoki
# needs them in the main package, because:
#   pkcs11_startup looks for opencryptoki/stdll/*.so, and
#   documentation suggests that programs should dlopen "PKCS11_API.so".
%dir %{_libdir}/opencryptoki
%{_libdir}/opencryptoki/libopencryptoki.*
%{_libdir}/opencryptoki/PKCS11_API.so
%dir %{_libdir}/opencryptoki/stdll
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/libopencryptoki.so
%{_libdir}/pkcs11/PKCS11_API.so
%{_libdir}/pkcs11/stdll

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files swtok
%{_libdir}/opencryptoki/stdll/libpkcs11_sw.*
%{_libdir}/opencryptoki/stdll/PKCS11_SW.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/swtok/
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/swtok/TOK_OBJ/

%files tpmtok
%doc doc/README.tpm_stdll
%{_libdir}/opencryptoki/stdll/libpkcs11_tpm.*
%{_libdir}/opencryptoki/stdll/PKCS11_TPM.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/tpm/

%files icsftok
%doc doc/README.icsf_stdll
%{_sbindir}/pkcsicsf
%{_mandir}/man1/pkcsicsf.1*
%{_libdir}/opencryptoki/stdll/libpkcs11_icsf.*
%{_libdir}/opencryptoki/stdll/PKCS11_ICSF.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/icsf/


%changelog
* Mon Sep 16 2024 daviddavid <daviddavid> 3.24.0-2.mga10
+ Revision: 2097253
- backport upstream patch to fix build on 32bit arches

* Fri Sep 13 2024 daviddavid <daviddavid> 3.24.0-1.mga10
+ Revision: 2095725
- new version 3.24.0
- enable pkcscca_migrate support
- remove i686 and arm support as upstream will get rid of 32-bit support
  https://github.com/opencryptoki/opencryptoki/issues/174

* Fri Apr 26 2024 ns80 <ns80> 3.23.0-2.mga10
+ Revision: 2061154
- fix user for pkcsslotd

* Mon Apr 22 2024 ns80 <ns80> 3.23.0-1.mga10
+ Revision: 2060467
- new version 3.23.0 for CVE-2024-0914 (mga#33124)

* Thu Nov 24 2022 daviddavid <daviddavid> 3.18.0-1.mga9
+ Revision: 1910665
- new version: 3.18.0
- fix json output
- add missing config file p11sak_defined_attrs.conf

* Wed Mar 30 2022 umeabot <umeabot> 3.16.0-4.mga9
+ Revision: 1833635
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 3.16.0-3.mga9
+ Revision: 1747426
- rebuild for openssl 3.0.0

* Fri Sep 10 2021 ns80 <ns80> 3.16.0-2.mga9
+ Revision: 1744996
- add patch from Ubuntu for security issue in handling EC keys (mga#29328)

* Fri Apr 09 2021 daviddavid <daviddavid> 3.16.0-1.mga9
+ Revision: 1714286
- new version: 3.16.0

* Thu Nov 19 2020 daviddavid <daviddavid> 3.15.1-1.mga8
+ Revision: 1647579
- new version: 3.15.1

* Thu Oct 22 2020 daviddavid <daviddavid> 3.15.0-1.mga8
+ Revision: 1638098
- new version: 3.15.0

* Wed Jun 24 2020 daviddavid <daviddavid> 3.14.0-1.mga8
+ Revision: 1599033
- new version: 3.14.0

* Sat May 02 2020 daviddavid <daviddavid> 3.13.0-1.mga8
+ Revision: 1577912
- new version: 3.13.0

* Thu Feb 20 2020 umeabot <umeabot> 3.12.1-2.mga8
+ Revision: 1546513
- Mageia 8 Mass Rebuild

* Mon Feb 03 2020 daviddavid <daviddavid> 3.12.1-1.mga8
+ Revision: 1486648
- new version: 3.12.1
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 13 2019 daviddavid <daviddavid> 3.12.0-1.mga8
+ Revision: 1459852
- new version: 3.12.0

* Fri Oct 11 2019 daviddavid <daviddavid> 3.11.1-1.mga8
+ Revision: 1451903
- new version: 3.11.1
- install pkcs11 module for opencryptoki to be usable from p11-kit

* Sat Mar 16 2019 daviddavid <daviddavid> 3.11.0-1.mga7
+ Revision: 1378042
- new version: 3.11.0
- ported root's group membership's patch for 3.11.0
- opencryptoki tools should inform the user that he is not in pkcs11 group
- fix failed to create directory or subvolume "/var/lock/opencryptoki"
- use upstream tmpfiles config

* Sun Sep 23 2018 umeabot <umeabot> 3.10.0-2.mga7
+ Revision: 1300004
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 daviddavid <daviddavid> 3.10.0-1.mga7
+ Revision: 1237617
- new version: 3.10.0

* Sat May 19 2018 daviddavid <daviddavid> 3.9.0-1.mga7
+ Revision: 1230426
- new version: 3.9.0
- remove merged upstream patch

* Thu Sep 07 2017 guillomovitch <guillomovitch> 3.7.0-1.mga7
+ Revision: 1151777
- new version 3.7.0
  drop s390-specific parts, we don't have such architecture

* Fri Aug 26 2016 luigiwalser <luigiwalser> 3.5-1.mga6
+ Revision: 1049124
- 3.5
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Nov 17 2015 oden <oden> 3.4-1.mga6
+ Revision: 903815
- attempt to fix the %%ghost stuff
- fix deps
- 3.4
- sync with fedora

* Mon Nov 09 2015 daviddavid <daviddavid> 2.4.2-5.mga6
+ Revision: 899897
- fix compilation with gcc5: add -fgnu89-inline to CFLAGS

* Wed Oct 15 2014 umeabot <umeabot> 2.4.2-4.mga5
+ Revision: 740493
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.4.2-3.mga5
+ Revision: 683201
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.4.2-2.mga4
+ Revision: 521330
- Mageia 4 Mass Rebuild

* Mon Jan 21 2013 oden <oden> 2.4.2-1.mga3
+ Revision: 390421
- don't ship the /var/lock/opencryptoki dir
- imported package opencryptoki


* Sun Jan 20 2013 Oden Eriksson <oeriksson@mandriva.com> 2.4.2-1.mga2
- fedora import (slightly)
